@@ -89,6 +89,46 @@ class Utility:
     """
     pass  # native code
 
+  @classmethod
+  def SerializeInt(cls, num):
+    """
+    Serializes an integer into a big-endian binary sequence.
+
+    :param num: an integer.
+    :return: The result binary sequence.
+    """
+    pass  # native code
+
+  @classmethod
+  def DeserializeInt(cls, data):
+    """
+    Deserializes a big-endian binary sequence into an integer.
+
+    :param data: a binary sequence.
+    :return: The result integer.
+    """
+    pass  # native code
+
+  @classmethod
+  def SerializeFloat(cls, num):
+    """
+    Serializes a floating-point number into a big-endian binary sequence.
+
+    :param num: a floating-point number.
+    :return: The result binary sequence.
+    """
+    pass  # native code
+
+  @classmethod
+  def DeserializeFloat(cls, data):
+    """
+    Deserializes a big-endian binary sequence into a floating-point number.
+
+    :param data: a binary sequence.
+    :return: The result floating-point number.
+    """
+    pass  # native code
+
 
 class Status:
   """
@@ -451,7 +491,7 @@ class DBM:
       - max_branches (int): The maximum number of branches each inner node can have.
       - max_cached_pages (int): The maximum number of cached pages.
       - page_update_mode (string): What to do when each page is updated: "PAGE_UPDATE_NONE" is to do no operation or "PAGE_UPDATE_WRITE" is to write immediately.
-      - key_comparator (string): The comparator of record keys: "LexicalKeyComparator" for the lexical order, "LexicalCaseKeyComparator" for the lexical order ignoring case, "DecimalKeyComparator" for the order of the decimal integer numeric expressions, "HexadecimalKeyComparator" for the order of the hexadecimal integer numeric expressions, "RealNumberKeyComparator" for the order of the decimal real number expressions.
+      - key_comparator (string): The comparator of record keys: "LexicalKeyComparator" for the lexical order, "LexicalCaseKeyComparator" for the lexical order ignoring case, "DecimalKeyComparator" for the order of decimal integer numeric expressions, "HexadecimalKeyComparator" for the order of hexadecimal integer numeric expressions, "RealNumberKeyComparator" for the order of decimal real number expressions, and "FloatBigEndianKeyComparator" for the order of binary float-number expressions.
 
     For SkipDBM, these optional parameters are supported.
       - offset_width (int): The width to represent the offset of records.
@@ -1640,7 +1680,7 @@ class Index:
     :param params: Optional keyword parameters.
     :return: The result status.
 
-    If the path is empty, BabyDBM is used internally, which is equivalent to using the MemIndex class.  If the path ends with ".tkt", TreeDBM is used internally, which is equivalent to using the FileIndex class.  If the key comparator of the tuning parameter is not set, PairLexicalKeyComparator is set implicitly.  Other compatible key comparators are PairLexicalCaseKeyComparator, PairDecimalKeyComparator, PairHexadecimalKeyComparator, and PairRealNumberKeyComparator.  Other options can be specified as with DBM::Open.
+    If the path is empty, BabyDBM is used internally, which is equivalent to using the MemIndex class.  If the path ends with ".tkt", TreeDBM is used internally, which is equivalent to using the FileIndex class.  If the key comparator of the tuning parameter is not set, PairLexicalKeyComparator is set implicitly.  Other compatible key comparators are PairLexicalCaseKeyComparator, PairDecimalKeyComparator, PairHexadecimalKeyComparator, PairRealNumberKeyComparator, and PairFloatBigEndianKeyComparator.  Other options can be specified as with DBM::Open.
     """
     pass  # native code
 
